pub struct WeekInformation(pub WeekInformation);Expand description
A Week calculator, useful to be passed in to week_of_year() on Date and DateTime types
Tuple Fields
0: WeekInformationImplementations
Sourceimpl WeekInformation
impl WeekInformation
Sourcepub fn create(locale: &Locale) -> Result<Box<WeekInformation>, DataError>
pub fn create(locale: &Locale) -> Result<Box<WeekInformation>, DataError>
Creates a new WeekInformation from locale data using compiled data.
Sourcepub fn first_weekday(&self) -> Weekday
pub fn first_weekday(&self) -> Weekday
Returns the weekday that starts the week for this object’s locale
pub fn is_weekend(&self, day: Weekday) -> bool
pub fn weekend(&self) -> Box<WeekdaySetIterator>